Index: kernel/generic/src/debug/symtab.c
===================================================================
--- kernel/generic/src/debug/symtab.c	(revision 22a28a696141d62f28e48ed72d1d255ff519795c)
+++ kernel/generic/src/debug/symtab.c	(revision c19aa612473b0cd0cc4282fabaaaea0f41fbb0b7)
@@ -46,7 +46,7 @@
 /** Get name of a symbol that seems most likely to correspond to address.
  *
- * @param addr		Address.
- * @param name		Place to store pointer to the symbol name.
- * @param offset	Place to store offset from the symbol address.
+ * @param addr   Address.
+ * @param name   Place to store pointer to the symbol name.
+ * @param offset Place to store offset from the symbol address.
  *
  * @return Zero on success or negative error code, ENOENT if not found,
@@ -83,6 +83,7 @@
 /** Lookup symbol by address and format for display.
  *
  * Returns name of closest corresponding symbol, "Not found" if none exists
  * or "N/A" if no symbol information is available.
  *
  * @param addr Address.
@@ -101,5 +102,5 @@
 		return name;
 	case ENOENT:
-		return "Not found";
+		return "unknown";
 	default:
 		return "N/A";
@@ -83,6 +83,7 @@
 /** Lookup symbol by address and format for display.
  *
- * Returns name of closest corresponding symbol, "Not found" if none exists
- * or "N/A" if no symbol information is available.
+ * Returns name of closest corresponding symbol,
+ * "unknown" if none exists and "N/A" if no symbol
+ * information is available.
  *
  * @param addr Address.
